==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/outputs/ContainerResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Container App container definition.
 * @property args Container start command arguments.
 * @property command Container start command.
 * @property env Container environment variables.
 * @property image Container image tag.
 * @property name Custom container name.
 * @property resources Container resource requirements.
 */
public data class ContainerResponse(
    public val args: List<String>? = null,
    public val command: List<String>? = null,
    public val env: List<EnvironmentVarResponse>? = null,
    public val image: String? = null,
    public val name: String? = null,
    public val resources: ContainerResourcesResponse? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.web.outputs.ContainerResponse):
            ContainerResponse = ContainerResponse(
            args = javaType.args().map({ args0 -> args0 }),
            command = javaType.command().map({ args0 -> args0 }),
            env = javaType.env().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.web.kotlin.outputs.EnvironmentVarResponse.Companion.toKotlin(args0)
                })
            }),
            image = javaType.image().map({ args0 -> args0 }).orElse(null),
            name = javaType.name().map({ args0 -> args0 }).orElse(null),
            resources = javaType.resources().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.web.kotlin.outputs.ContainerResourcesResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/web/kotlin/outputs/ContainerResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Container App container definition.
 * @property args Container start command arguments.
 * @property command Container start command.
 * @property env Container environment variables.
 * @property image Container image tag.
 * @property name Custom container name.
 * @property resources Container resource requirements.
 */
public data class ContainerResponse(
    public val args: List<String>? = null,
    public val command: List<String>? = null,
    public val env: List<EnvironmentVarResponse>? = null,
    public val image: String? = null,
    public val name: String? = null,
    public val resources: ContainerResourcesResponse? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.web.outputs.ContainerResponse): ContainerResponse = ContainerResponse(
            args = javaType.args().map({ args0 -> args0 }),
            command = javaType.command().map({ args0 -> args0 }),
            env = javaType.env().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.web.kotlin.outputs.EnvironmentVarResponse.Companion.toKotlin(args0)
                })
            }),
            image = javaType.image().map({ args0 -> args0 }).orElse(null),
            name = javaType.name().map({ args0 -> args0 }).orElse(null),
            resources = javaType.resources().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.web.kotlin.outputs.ContainerResourcesResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}
